from setuptools import setup
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name = "reflex-icons",
    version = "1.0.0",
    author="Saurabh Wadekar [ INDIA ]",
    packages=["reflex_icons"],
    license="MIT",
    maintainer="Saurabh Wadekar",
    maintainer_email="saurabhwadekar420@gmail.com",
    keywords=["react icons","icons","reflex-icons","reflex"],
    description=" This library provides all icons of React-icons wrapped for ReFlex framework",
    long_description=long_description,
    long_description_content_type='text/markdown',
    url="https://github.com/saurabhwadekar/Reflex-Icons",
    include_package_data=True,
    install_requires=[
        "reflex",
    ],
)


import reflex as rx

class TfiAgenda(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAgenda"


class TfiAlarmClock(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAlarmClock"


class TfiAlert(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAlert"


class TfiAlignCenter(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAlignCenter"


class TfiAlignJustify(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAlignJustify"


class TfiAlignLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAlignLeft"


class TfiAlignRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAlignRight"


class TfiAnchor(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAnchor"


class TfiAndroid(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAndroid"


class TfiAngleDoubleDown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAngleDoubleDown"


class TfiAngleDoubleLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAngleDoubleLeft"


class TfiAngleDoubleRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAngleDoubleRight"


class TfiAngleDoubleUp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAngleDoubleUp"


class TfiAngleDown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAngleDown"


class TfiAngleLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAngleLeft"


class TfiAngleRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAngleRight"


class TfiAngleUp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAngleUp"


class TfiAnnouncement(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAnnouncement"


class TfiApple(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiApple"


class TfiArchive(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArchive"


class TfiArrowCircleDown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowCircleDown"


class TfiArrowCircleLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowCircleLeft"


class TfiArrowCircleRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowCircleRight"


class TfiArrowCircleUp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowCircleUp"


class TfiArrowDown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowDown"


class TfiArrowLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowLeft"


class TfiArrowRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowRight"


class TfiArrowTopLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowTopLeft"


class TfiArrowTopRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowTopRight"


class TfiArrowUp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowUp"


class TfiArrow(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrow"


class TfiArrowsCorner(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowsCorner"


class TfiArrowsHorizontal(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowsHorizontal"


class TfiArrowsVertical(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowsVertical"


class TfiBackLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBackLeft"


class TfiBackRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBackRight"


class TfiBag(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBag"


class TfiBarChartAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBarChartAlt"


class TfiBarChart(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBarChart"


class TfiBasketball(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBasketball"


class TfiBell(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBell"


class TfiBlackboard(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBlackboard"


class TfiBoltAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBoltAlt"


class TfiBolt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBolt"


class TfiBook(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBook"


class TfiBookmarkAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBookmarkAlt"


class TfiBookmark(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBookmark"


class TfiBriefcase(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBriefcase"


class TfiBrushAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBrushAlt"


class TfiBrush(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBrush"


class TfiCalendar(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCalendar"


class TfiCamera(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCamera"


class TfiCar(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCar"


class TfiCheckBox(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCheckBox"


class TfiCheck(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCheck"


class TfiClip(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiClip"


class TfiClipboard(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiClipboard"


class TfiClose(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiClose"


class TfiCloudDown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCloudDown"


class TfiCloudUp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCloudUp"


class TfiCloud(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCloud"


class TfiCommentAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCommentAlt"


class TfiComment(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiComment"


class TfiCommentsSmiley(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCommentsSmiley"


class TfiComments(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiComments"


class TfiControlBackward(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlBackward"


class TfiControlEject(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlEject"


class TfiControlForward(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlForward"


class TfiControlPause(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlPause"


class TfiControlPlay(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlPlay"


class TfiControlRecord(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlRecord"


class TfiControlShuffle(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlShuffle"


class TfiControlSkipBackward(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlSkipBackward"


class TfiControlSkipForward(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlSkipForward"


class TfiControlStop(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlStop"


class TfiCreditCard(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCreditCard"


class TfiCrown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCrown"


class TfiCss3(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCss3"


class TfiCup(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCup"


class TfiCut(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCut"


class TfiDashboard(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDashboard"


class TfiDesktop(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDesktop"


class TfiDirectionAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDirectionAlt"


class TfiDirection(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDirection"


class TfiDownload(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDownload"


class TfiDribbble(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDribbble"


class TfiDropboxAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDropboxAlt"


class TfiDropbox(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDropbox"


class TfiDrupal(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDrupal"


class TfiEmail(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiEmail"


class TfiEnvelope(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiEnvelope"


class TfiEraser(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiEraser"


class TfiExchangeVertical(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiExchangeVertical"


class TfiExport(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiExport"


class TfiEye(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiEye"


class TfiFaceSad(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFaceSad"


class TfiFaceSmile(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFaceSmile"


class TfiFacebook(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFacebook"


class TfiFile(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFile"


class TfiFiles(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFiles"


class TfiFilter(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFilter"


class TfiFlagAlt2(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFlagAlt2"


class TfiFlagAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFlagAlt"


class TfiFlag(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFlag"


class TfiFlickrAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFlickrAlt"


class TfiFlickr(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFlickr"


class TfiFolder(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFolder"


class TfiFullscreen(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFullscreen"


class TfiGallery(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiGallery"


class TfiGame(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiGame"


class TfiGift(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiGift"


class TfiGithub(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiGithub"


class TfiGoogle(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiGoogle"


class TfiHandDrag(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHandDrag"


class TfiHandOpen(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHandOpen"


class TfiHandPointDown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHandPointDown"


class TfiHandPointLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHandPointLeft"


class TfiHandPointRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHandPointRight"


class TfiHandPointUp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHandPointUp"


class TfiHandStop(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHandStop"


class TfiHarddrive(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHarddrive"


class TfiHarddrives(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHarddrives"


class TfiHeadphoneAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHeadphoneAlt"


class TfiHeadphone(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHeadphone"


class TfiHeartBroken(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHeartBroken"


class TfiHeart(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHeart"


class TfiHelpAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHelpAlt"


class TfiHelp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHelp"


class TfiHome(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHome"


class TfiHtml5(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHtml5"


class TfiHummer(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHummer"


class TfiIdBadge(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiIdBadge"


class TfiImage(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiImage"


class TfiImport(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiImport"


class TfiInfinite(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiInfinite"


class TfiInfoAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiInfoAlt"


class TfiInfo(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiInfo"


class TfiInkPen(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiInkPen"


class TfiInstagram(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiInstagram"


class TfiItalic(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiItalic"


class TfiJoomla(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiJoomla"


class TfiJsfiddle(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiJsfiddle"


class TfiKey(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiKey"


class TfiLayersAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayersAlt"


class TfiLayers(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayers"


class TfiLayoutAccordionList(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutAccordionList"


class TfiLayoutAccordionMerged(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutAccordionMerged"


class TfiLayoutAccordionSeparated(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutAccordionSeparated"


class TfiLayoutColumn2Alt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutColumn2Alt"


class TfiLayoutColumn2(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutColumn2"


class TfiLayoutColumn3Alt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutColumn3Alt"


class TfiLayoutColumn3(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutColumn3"


class TfiLayoutColumn4Alt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutColumn4Alt"


class TfiLayoutColumn4(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutColumn4"


class TfiLayoutCtaBtnLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutCtaBtnLeft"


class TfiLayoutCtaBtnRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutCtaBtnRight"


class TfiLayoutCtaCenter(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutCtaCenter"


class TfiLayoutCtaLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutCtaLeft"


class TfiLayoutCtaRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutCtaRight"


class TfiLayoutGrid2Alt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutGrid2Alt"


class TfiLayoutGrid2Thumb(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutGrid2Thumb"


class TfiLayoutGrid2(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutGrid2"


class TfiLayoutGrid3Alt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutGrid3Alt"


class TfiLayoutGrid3(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutGrid3"


class TfiLayoutGrid4Alt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutGrid4Alt"


class TfiLayoutGrid4(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutGrid4"


class TfiLayoutLineSolid(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutLineSolid"


class TfiLayoutListLargeImage(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutListLargeImage"


class TfiLayoutListPost(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutListPost"


class TfiLayoutListThumbAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutListThumbAlt"


class TfiLayoutListThumb(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutListThumb"


class TfiLayoutMediaCenterAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaCenterAlt"


class TfiLayoutMediaCenter(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaCenter"


class TfiLayoutMediaLeftAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaLeftAlt"


class TfiLayoutMediaLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaLeft"


class TfiLayoutMediaOverlayAlt2(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaOverlayAlt2"


class TfiLayoutMediaOverlayAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaOverlayAlt"


class TfiLayoutMediaOverlay(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaOverlay"


class TfiLayoutMediaRightAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaRightAlt"


class TfiLayoutMediaRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaRight"


class TfiLayoutMenuFull(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMenuFull"


class TfiLayoutMenuSeparated(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMenuSeparated"


class TfiLayoutMenuV(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMenuV"


class TfiLayoutMenu(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMenu"


class TfiLayoutPlaceholder(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutPlaceholder"


class TfiLayoutSidebar2(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutSidebar2"


class TfiLayoutSidebarLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutSidebarLeft"


class TfiLayoutSidebarNone(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutSidebarNone"


class TfiLayoutSidebarRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutSidebarRight"


class TfiLayoutSliderAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutSliderAlt"


class TfiLayoutSlider(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutSlider"


class TfiLayoutTabMin(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutTabMin"


class TfiLayoutTabV(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutTabV"


class TfiLayoutTabWindow(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutTabWindow"


class TfiLayoutTab(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutTab"


class TfiLayoutWidthDefaultAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutWidthDefaultAlt"


class TfiLayoutWidthDefault(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutWidthDefault"


class TfiLayoutWidthFull(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutWidthFull"


class TfiLayout(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayout"


class TfiLightBulb(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLightBulb"


class TfiLineDashed(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLineDashed"


class TfiLineDotted(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLineDotted"


class TfiLineDouble(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLineDouble"


class TfiLink(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLink"


class TfiLinkedin(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLinkedin"


class TfiLinux(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLinux"


class TfiListOl(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiListOl"


class TfiList(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiList"


class TfiLocationArrow(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLocationArrow"


class TfiLocationPin(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLocationPin"


class TfiLock(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLock"


class TfiLoop(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLoop"


class TfiMagnet(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMagnet"


class TfiMapAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMapAlt"


class TfiMap(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMap"


class TfiMarkerAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMarkerAlt"


class TfiMarker(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMarker"


class TfiMedallAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMedallAlt"


class TfiMedall(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMedall"


class TfiMenuAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMenuAlt"


class TfiMenu(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMenu"


class TfiMicrophoneAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMicrophoneAlt"


class TfiMicrophone(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMicrophone"


class TfiMicrosoftAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMicrosoftAlt"


class TfiMicrosoft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMicrosoft"


class TfiMinus(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMinus"


class TfiMobile(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMobile"


class TfiMoney(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMoney"


class TfiMoreAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMoreAlt"


class TfiMore(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMore"


class TfiMouseAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMouseAlt"


class TfiMouse(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMouse"


class TfiMusicAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMusicAlt"


class TfiMusic(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMusic"


class TfiNa(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiNa"


class TfiNewWindow(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiNewWindow"


class TfiNotepad(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiNotepad"


class TfiPackage(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPackage"


class TfiPaintBucket(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPaintBucket"


class TfiPaintRoller(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPaintRoller"


class TfiPalette(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPalette"


class TfiPanel(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPanel"


class TfiParagraph(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiParagraph"


class TfiPencilAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPencilAlt"


class TfiPencilAlt2(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPencilAlt2"


class TfiPencil(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPencil"


class TfiPieChart(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPieChart"


class TfiPinAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPinAlt"


class TfiPin(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPin"


class TfiPin2(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPin2"


class TfiPinterestAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPinterestAlt"


class TfiPinterest(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPinterest"


class TfiPlug(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPlug"


class TfiPlus(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPlus"


class TfiPowerOff(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPowerOff"


class TfiPrinter(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPrinter"


class TfiPulse(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPulse"


class TfiQuoteLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiQuoteLeft"


class TfiQuoteRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiQuoteRight"


class TfiReceipt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiReceipt"


class TfiReddit(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiReddit"


class TfiReload(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiReload"


class TfiRocket(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiRocket"


class TfiRssAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiRssAlt"


class TfiRss(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiRss"


class TfiRulerAlt2(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiRulerAlt2"


class TfiRulerAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiRulerAlt"


class TfiRulerPencil(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiRulerPencil"


class TfiRuler(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiRuler"


class TfiSaveAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSaveAlt"


class TfiSave(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSave"


class TfiSearch(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSearch"


class TfiServer(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiServer"


class TfiSettings(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSettings"


class TfiShareAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShareAlt"


class TfiShare(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShare"


class TfiSharethisAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSharethisAlt"


class TfiSharethis(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSharethis"


class TfiShield(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShield"


class TfiShiftLeftAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShiftLeftAlt"


class TfiShiftLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShiftLeft"


class TfiShiftRightAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShiftRightAlt"


class TfiShiftRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShiftRight"


class TfiShine(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShine"


class TfiShoppingCartFull(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShoppingCartFull"


class TfiShoppingCart(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShoppingCart"


class TfiShortcode(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShortcode"


class TfiSignal(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSignal"


class TfiSkype(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSkype"


class TfiSlice(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSlice"


class TfiSmallcap(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSmallcap"


class TfiSoundcloud(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSoundcloud"


class TfiSplitH(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSplitH"


class TfiSplitVAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSplitVAlt"


class TfiSplitV(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSplitV"


class TfiSpray(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSpray"


class TfiStackOverflow(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiStackOverflow"


class TfiStamp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiStamp"


class TfiStar(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiStar"


class TfiStatsDown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiStatsDown"


class TfiStatsUp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiStatsUp"


class TfiSupport(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSupport"


class TfiTablet(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTablet"


class TfiTag(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTag"


class TfiTarget(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTarget"


class TfiText(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiText"


class TfiThemifyFaviconAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiThemifyFaviconAlt"


class TfiThemifyFavicon(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiThemifyFavicon"


class TfiThemifyLogo(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiThemifyLogo"


class TfiThought(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiThought"


class TfiThumbDown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiThumbDown"


class TfiThumbUp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiThumbUp"


class TfiTicket(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTicket"


class TfiTime(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTime"


class TfiTimer(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTimer"


class TfiTrash(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTrash"


class TfiTrello(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTrello"


class TfiTruck(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTruck"


class TfiTumblrAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTumblrAlt"


class TfiTumblr(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTumblr"


class TfiTwitterAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTwitterAlt"


class TfiTwitter(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTwitter"


class TfiUnderline(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiUnderline"


class TfiUnlink(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiUnlink"


class TfiUnlock(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiUnlock"


class TfiUpload(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiUpload"


class TfiUppercase(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiUppercase"


class TfiUser(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiUser"


class TfiVector(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiVector"


class TfiVideoCamera(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiVideoCamera"


class TfiVideoClapper(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiVideoClapper"


class TfiViewGrid(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiViewGrid"


class TfiViewListAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiViewListAlt"


class TfiViewList(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiViewList"


class TfiVimeoAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiVimeoAlt"


class TfiVimeo(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiVimeo"


class TfiVolume(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiVolume"


class TfiWallet(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWallet"


class TfiWand(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWand"


class TfiWheelchair(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWheelchair"


class TfiWidgetAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWidgetAlt"


class TfiWidget(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWidget"


class TfiWidgetized(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWidgetized"


class TfiWindow(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWindow"


class TfiWordpress(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWordpress"


class TfiWorld(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWorld"


class TfiWrite(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWrite"


class TfiYahoo(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiYahoo"


class TfiYoutube(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiYoutube"


class TfiZip(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiZip"


class TfiZoomIn(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiZoomIn"


class TfiZoomOut(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiZoomOut"





import reflex as rx

class FiActivity(rx.Component):
    library = "react-icons/fi"
    tag = "FiActivity"


class FiAirplay(rx.Component):
    library = "react-icons/fi"
    tag = "FiAirplay"


class FiAlertCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiAlertCircle"


class FiAlertOctagon(rx.Component):
    library = "react-icons/fi"
    tag = "FiAlertOctagon"


class FiAlertTriangle(rx.Component):
    library = "react-icons/fi"
    tag = "FiAlertTriangle"


class FiAlignCenter(rx.Component):
    library = "react-icons/fi"
    tag = "FiAlignCenter"


class FiAlignJustify(rx.Component):
    library = "react-icons/fi"
    tag = "FiAlignJustify"


class FiAlignLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiAlignLeft"


class FiAlignRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiAlignRight"


class FiAnchor(rx.Component):
    library = "react-icons/fi"
    tag = "FiAnchor"


class FiAperture(rx.Component):
    library = "react-icons/fi"
    tag = "FiAperture"


class FiArchive(rx.Component):
    library = "react-icons/fi"
    tag = "FiArchive"


class FiArrowDownCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowDownCircle"


class FiArrowDownLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowDownLeft"


class FiArrowDownRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowDownRight"


class FiArrowDown(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowDown"


class FiArrowLeftCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowLeftCircle"


class FiArrowLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowLeft"


class FiArrowRightCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowRightCircle"


class FiArrowRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowRight"


class FiArrowUpCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowUpCircle"


class FiArrowUpLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowUpLeft"


class FiArrowUpRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowUpRight"


class FiArrowUp(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowUp"


class FiAtSign(rx.Component):
    library = "react-icons/fi"
    tag = "FiAtSign"


class FiAward(rx.Component):
    library = "react-icons/fi"
    tag = "FiAward"


class FiBarChart2(rx.Component):
    library = "react-icons/fi"
    tag = "FiBarChart2"


class FiBarChart(rx.Component):
    library = "react-icons/fi"
    tag = "FiBarChart"


class FiBatteryCharging(rx.Component):
    library = "react-icons/fi"
    tag = "FiBatteryCharging"


class FiBattery(rx.Component):
    library = "react-icons/fi"
    tag = "FiBattery"


class FiBellOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiBellOff"


class FiBell(rx.Component):
    library = "react-icons/fi"
    tag = "FiBell"


class FiBluetooth(rx.Component):
    library = "react-icons/fi"
    tag = "FiBluetooth"


class FiBold(rx.Component):
    library = "react-icons/fi"
    tag = "FiBold"


class FiBookOpen(rx.Component):
    library = "react-icons/fi"
    tag = "FiBookOpen"


class FiBook(rx.Component):
    library = "react-icons/fi"
    tag = "FiBook"


class FiBookmark(rx.Component):
    library = "react-icons/fi"
    tag = "FiBookmark"


class FiBox(rx.Component):
    library = "react-icons/fi"
    tag = "FiBox"


class FiBriefcase(rx.Component):
    library = "react-icons/fi"
    tag = "FiBriefcase"


class FiCalendar(rx.Component):
    library = "react-icons/fi"
    tag = "FiCalendar"


class FiCameraOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiCameraOff"


class FiCamera(rx.Component):
    library = "react-icons/fi"
    tag = "FiCamera"


class FiCast(rx.Component):
    library = "react-icons/fi"
    tag = "FiCast"


class FiCheckCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiCheckCircle"


class FiCheckSquare(rx.Component):
    library = "react-icons/fi"
    tag = "FiCheckSquare"


class FiCheck(rx.Component):
    library = "react-icons/fi"
    tag = "FiCheck"


class FiChevronDown(rx.Component):
    library = "react-icons/fi"
    tag = "FiChevronDown"


class FiChevronLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiChevronLeft"


class FiChevronRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiChevronRight"


class FiChevronUp(rx.Component):
    library = "react-icons/fi"
    tag = "FiChevronUp"


class FiChevronsDown(rx.Component):
    library = "react-icons/fi"
    tag = "FiChevronsDown"


class FiChevronsLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiChevronsLeft"


class FiChevronsRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiChevronsRight"


class FiChevronsUp(rx.Component):
    library = "react-icons/fi"
    tag = "FiChevronsUp"


class FiChrome(rx.Component):
    library = "react-icons/fi"
    tag = "FiChrome"


class FiCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiCircle"


class FiClipboard(rx.Component):
    library = "react-icons/fi"
    tag = "FiClipboard"


class FiClock(rx.Component):
    library = "react-icons/fi"
    tag = "FiClock"


class FiCloudDrizzle(rx.Component):
    library = "react-icons/fi"
    tag = "FiCloudDrizzle"


class FiCloudLightning(rx.Component):
    library = "react-icons/fi"
    tag = "FiCloudLightning"


class FiCloudOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiCloudOff"


class FiCloudRain(rx.Component):
    library = "react-icons/fi"
    tag = "FiCloudRain"


class FiCloudSnow(rx.Component):
    library = "react-icons/fi"
    tag = "FiCloudSnow"


class FiCloud(rx.Component):
    library = "react-icons/fi"
    tag = "FiCloud"


class FiCode(rx.Component):
    library = "react-icons/fi"
    tag = "FiCode"


class FiCodepen(rx.Component):
    library = "react-icons/fi"
    tag = "FiCodepen"


class FiCodesandbox(rx.Component):
    library = "react-icons/fi"
    tag = "FiCodesandbox"


class FiCoffee(rx.Component):
    library = "react-icons/fi"
    tag = "FiCoffee"


class FiColumns(rx.Component):
    library = "react-icons/fi"
    tag = "FiColumns"


class FiCommand(rx.Component):
    library = "react-icons/fi"
    tag = "FiCommand"


class FiCompass(rx.Component):
    library = "react-icons/fi"
    tag = "FiCompass"


class FiCopy(rx.Component):
    library = "react-icons/fi"
    tag = "FiCopy"


class FiCornerDownLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiCornerDownLeft"


class FiCornerDownRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiCornerDownRight"


class FiCornerLeftDown(rx.Component):
    library = "react-icons/fi"
    tag = "FiCornerLeftDown"


class FiCornerLeftUp(rx.Component):
    library = "react-icons/fi"
    tag = "FiCornerLeftUp"


class FiCornerRightDown(rx.Component):
    library = "react-icons/fi"
    tag = "FiCornerRightDown"


class FiCornerRightUp(rx.Component):
    library = "react-icons/fi"
    tag = "FiCornerRightUp"


class FiCornerUpLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiCornerUpLeft"


class FiCornerUpRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiCornerUpRight"


class FiCpu(rx.Component):
    library = "react-icons/fi"
    tag = "FiCpu"


class FiCreditCard(rx.Component):
    library = "react-icons/fi"
    tag = "FiCreditCard"


class FiCrop(rx.Component):
    library = "react-icons/fi"
    tag = "FiCrop"


class FiCrosshair(rx.Component):
    library = "react-icons/fi"
    tag = "FiCrosshair"


class FiDatabase(rx.Component):
    library = "react-icons/fi"
    tag = "FiDatabase"


class FiDelete(rx.Component):
    library = "react-icons/fi"
    tag = "FiDelete"


class FiDisc(rx.Component):
    library = "react-icons/fi"
    tag = "FiDisc"


class FiDivideCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiDivideCircle"


class FiDivideSquare(rx.Component):
    library = "react-icons/fi"
    tag = "FiDivideSquare"


class FiDivide(rx.Component):
    library = "react-icons/fi"
    tag = "FiDivide"


class FiDollarSign(rx.Component):
    library = "react-icons/fi"
    tag = "FiDollarSign"


class FiDownloadCloud(rx.Component):
    library = "react-icons/fi"
    tag = "FiDownloadCloud"


class FiDownload(rx.Component):
    library = "react-icons/fi"
    tag = "FiDownload"


class FiDribbble(rx.Component):
    library = "react-icons/fi"
    tag = "FiDribbble"


class FiDroplet(rx.Component):
    library = "react-icons/fi"
    tag = "FiDroplet"


class FiEdit2(rx.Component):
    library = "react-icons/fi"
    tag = "FiEdit2"


class FiEdit3(rx.Component):
    library = "react-icons/fi"
    tag = "FiEdit3"


class FiEdit(rx.Component):
    library = "react-icons/fi"
    tag = "FiEdit"


class FiExternalLink(rx.Component):
    library = "react-icons/fi"
    tag = "FiExternalLink"


class FiEyeOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiEyeOff"


class FiEye(rx.Component):
    library = "react-icons/fi"
    tag = "FiEye"


class FiFacebook(rx.Component):
    library = "react-icons/fi"
    tag = "FiFacebook"


class FiFastForward(rx.Component):
    library = "react-icons/fi"
    tag = "FiFastForward"


class FiFeather(rx.Component):
    library = "react-icons/fi"
    tag = "FiFeather"


class FiFigma(rx.Component):
    library = "react-icons/fi"
    tag = "FiFigma"


class FiFileMinus(rx.Component):
    library = "react-icons/fi"
    tag = "FiFileMinus"


class FiFilePlus(rx.Component):
    library = "react-icons/fi"
    tag = "FiFilePlus"


class FiFileText(rx.Component):
    library = "react-icons/fi"
    tag = "FiFileText"


class FiFile(rx.Component):
    library = "react-icons/fi"
    tag = "FiFile"


class FiFilm(rx.Component):
    library = "react-icons/fi"
    tag = "FiFilm"


class FiFilter(rx.Component):
    library = "react-icons/fi"
    tag = "FiFilter"


class FiFlag(rx.Component):
    library = "react-icons/fi"
    tag = "FiFlag"


class FiFolderMinus(rx.Component):
    library = "react-icons/fi"
    tag = "FiFolderMinus"


class FiFolderPlus(rx.Component):
    library = "react-icons/fi"
    tag = "FiFolderPlus"


class FiFolder(rx.Component):
    library = "react-icons/fi"
    tag = "FiFolder"


class FiFramer(rx.Component):
    library = "react-icons/fi"
    tag = "FiFramer"


class FiFrown(rx.Component):
    library = "react-icons/fi"
    tag = "FiFrown"


class FiGift(rx.Component):
    library = "react-icons/fi"
    tag = "FiGift"


class FiGitBranch(rx.Component):
    library = "react-icons/fi"
    tag = "FiGitBranch"


class FiGitCommit(rx.Component):
    library = "react-icons/fi"
    tag = "FiGitCommit"


class FiGitMerge(rx.Component):
    library = "react-icons/fi"
    tag = "FiGitMerge"


class FiGitPullRequest(rx.Component):
    library = "react-icons/fi"
    tag = "FiGitPullRequest"


class FiGithub(rx.Component):
    library = "react-icons/fi"
    tag = "FiGithub"


class FiGitlab(rx.Component):
    library = "react-icons/fi"
    tag = "FiGitlab"


class FiGlobe(rx.Component):
    library = "react-icons/fi"
    tag = "FiGlobe"


class FiGrid(rx.Component):
    library = "react-icons/fi"
    tag = "FiGrid"


class FiHardDrive(rx.Component):
    library = "react-icons/fi"
    tag = "FiHardDrive"


class FiHash(rx.Component):
    library = "react-icons/fi"
    tag = "FiHash"


class FiHeadphones(rx.Component):
    library = "react-icons/fi"
    tag = "FiHeadphones"


class FiHeart(rx.Component):
    library = "react-icons/fi"
    tag = "FiHeart"


class FiHelpCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiHelpCircle"


class FiHexagon(rx.Component):
    library = "react-icons/fi"
    tag = "FiHexagon"


class FiHome(rx.Component):
    library = "react-icons/fi"
    tag = "FiHome"


class FiImage(rx.Component):
    library = "react-icons/fi"
    tag = "FiImage"


class FiInbox(rx.Component):
    library = "react-icons/fi"
    tag = "FiInbox"


class FiInfo(rx.Component):
    library = "react-icons/fi"
    tag = "FiInfo"


class FiInstagram(rx.Component):
    library = "react-icons/fi"
    tag = "FiInstagram"


class FiItalic(rx.Component):
    library = "react-icons/fi"
    tag = "FiItalic"


class FiKey(rx.Component):
    library = "react-icons/fi"
    tag = "FiKey"


class FiLayers(rx.Component):
    library = "react-icons/fi"
    tag = "FiLayers"


class FiLayout(rx.Component):
    library = "react-icons/fi"
    tag = "FiLayout"


class FiLifeBuoy(rx.Component):
    library = "react-icons/fi"
    tag = "FiLifeBuoy"


class FiLink2(rx.Component):
    library = "react-icons/fi"
    tag = "FiLink2"


class FiLink(rx.Component):
    library = "react-icons/fi"
    tag = "FiLink"


class FiLinkedin(rx.Component):
    library = "react-icons/fi"
    tag = "FiLinkedin"


class FiList(rx.Component):
    library = "react-icons/fi"
    tag = "FiList"


class FiLoader(rx.Component):
    library = "react-icons/fi"
    tag = "FiLoader"


class FiLock(rx.Component):
    library = "react-icons/fi"
    tag = "FiLock"


class FiLogIn(rx.Component):
    library = "react-icons/fi"
    tag = "FiLogIn"


class FiLogOut(rx.Component):
    library = "react-icons/fi"
    tag = "FiLogOut"


class FiMail(rx.Component):
    library = "react-icons/fi"
    tag = "FiMail"


class FiMapPin(rx.Component):
    library = "react-icons/fi"
    tag = "FiMapPin"


class FiMap(rx.Component):
    library = "react-icons/fi"
    tag = "FiMap"


class FiMaximize2(rx.Component):
    library = "react-icons/fi"
    tag = "FiMaximize2"


class FiMaximize(rx.Component):
    library = "react-icons/fi"
    tag = "FiMaximize"


class FiMeh(rx.Component):
    library = "react-icons/fi"
    tag = "FiMeh"


class FiMenu(rx.Component):
    library = "react-icons/fi"
    tag = "FiMenu"


class FiMessageCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiMessageCircle"


class FiMessageSquare(rx.Component):
    library = "react-icons/fi"
    tag = "FiMessageSquare"


class FiMicOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiMicOff"


class FiMic(rx.Component):
    library = "react-icons/fi"
    tag = "FiMic"


class FiMinimize2(rx.Component):
    library = "react-icons/fi"
    tag = "FiMinimize2"


class FiMinimize(rx.Component):
    library = "react-icons/fi"
    tag = "FiMinimize"


class FiMinusCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiMinusCircle"


class FiMinusSquare(rx.Component):
    library = "react-icons/fi"
    tag = "FiMinusSquare"


class FiMinus(rx.Component):
    library = "react-icons/fi"
    tag = "FiMinus"


class FiMonitor(rx.Component):
    library = "react-icons/fi"
    tag = "FiMonitor"


class FiMoon(rx.Component):
    library = "react-icons/fi"
    tag = "FiMoon"


class FiMoreHorizontal(rx.Component):
    library = "react-icons/fi"
    tag = "FiMoreHorizontal"


class FiMoreVertical(rx.Component):
    library = "react-icons/fi"
    tag = "FiMoreVertical"


class FiMousePointer(rx.Component):
    library = "react-icons/fi"
    tag = "FiMousePointer"


class FiMove(rx.Component):
    library = "react-icons/fi"
    tag = "FiMove"


class FiMusic(rx.Component):
    library = "react-icons/fi"
    tag = "FiMusic"


class FiNavigation2(rx.Component):
    library = "react-icons/fi"
    tag = "FiNavigation2"


class FiNavigation(rx.Component):
    library = "react-icons/fi"
    tag = "FiNavigation"


class FiOctagon(rx.Component):
    library = "react-icons/fi"
    tag = "FiOctagon"


class FiPackage(rx.Component):
    library = "react-icons/fi"
    tag = "FiPackage"


class FiPaperclip(rx.Component):
    library = "react-icons/fi"
    tag = "FiPaperclip"


class FiPauseCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiPauseCircle"


class FiPause(rx.Component):
    library = "react-icons/fi"
    tag = "FiPause"


class FiPenTool(rx.Component):
    library = "react-icons/fi"
    tag = "FiPenTool"


class FiPercent(rx.Component):
    library = "react-icons/fi"
    tag = "FiPercent"


class FiPhoneCall(rx.Component):
    library = "react-icons/fi"
    tag = "FiPhoneCall"


class FiPhoneForwarded(rx.Component):
    library = "react-icons/fi"
    tag = "FiPhoneForwarded"


class FiPhoneIncoming(rx.Component):
    library = "react-icons/fi"
    tag = "FiPhoneIncoming"


class FiPhoneMissed(rx.Component):
    library = "react-icons/fi"
    tag = "FiPhoneMissed"


class FiPhoneOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiPhoneOff"


class FiPhoneOutgoing(rx.Component):
    library = "react-icons/fi"
    tag = "FiPhoneOutgoing"


class FiPhone(rx.Component):
    library = "react-icons/fi"
    tag = "FiPhone"


class FiPieChart(rx.Component):
    library = "react-icons/fi"
    tag = "FiPieChart"


class FiPlayCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiPlayCircle"


class FiPlay(rx.Component):
    library = "react-icons/fi"
    tag = "FiPlay"


class FiPlusCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiPlusCircle"


class FiPlusSquare(rx.Component):
    library = "react-icons/fi"
    tag = "FiPlusSquare"


class FiPlus(rx.Component):
    library = "react-icons/fi"
    tag = "FiPlus"


class FiPocket(rx.Component):
    library = "react-icons/fi"
    tag = "FiPocket"


class FiPower(rx.Component):
    library = "react-icons/fi"
    tag = "FiPower"


class FiPrinter(rx.Component):
    library = "react-icons/fi"
    tag = "FiPrinter"


class FiRadio(rx.Component):
    library = "react-icons/fi"
    tag = "FiRadio"


class FiRefreshCcw(rx.Component):
    library = "react-icons/fi"
    tag = "FiRefreshCcw"


class FiRefreshCw(rx.Component):
    library = "react-icons/fi"
    tag = "FiRefreshCw"


class FiRepeat(rx.Component):
    library = "react-icons/fi"
    tag = "FiRepeat"


class FiRewind(rx.Component):
    library = "react-icons/fi"
    tag = "FiRewind"


class FiRotateCcw(rx.Component):
    library = "react-icons/fi"
    tag = "FiRotateCcw"


class FiRotateCw(rx.Component):
    library = "react-icons/fi"
    tag = "FiRotateCw"


class FiRss(rx.Component):
    library = "react-icons/fi"
    tag = "FiRss"


class FiSave(rx.Component):
    library = "react-icons/fi"
    tag = "FiSave"


class FiScissors(rx.Component):
    library = "react-icons/fi"
    tag = "FiScissors"


class FiSearch(rx.Component):
    library = "react-icons/fi"
    tag = "FiSearch"


class FiSend(rx.Component):
    library = "react-icons/fi"
    tag = "FiSend"


class FiServer(rx.Component):
    library = "react-icons/fi"
    tag = "FiServer"


class FiSettings(rx.Component):
    library = "react-icons/fi"
    tag = "FiSettings"


class FiShare2(rx.Component):
    library = "react-icons/fi"
    tag = "FiShare2"


class FiShare(rx.Component):
    library = "react-icons/fi"
    tag = "FiShare"


class FiShieldOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiShieldOff"


class FiShield(rx.Component):
    library = "react-icons/fi"
    tag = "FiShield"


class FiShoppingBag(rx.Component):
    library = "react-icons/fi"
    tag = "FiShoppingBag"


class FiShoppingCart(rx.Component):
    library = "react-icons/fi"
    tag = "FiShoppingCart"


class FiShuffle(rx.Component):
    library = "react-icons/fi"
    tag = "FiShuffle"


class FiSidebar(rx.Component):
    library = "react-icons/fi"
    tag = "FiSidebar"


class FiSkipBack(rx.Component):
    library = "react-icons/fi"
    tag = "FiSkipBack"


class FiSkipForward(rx.Component):
    library = "react-icons/fi"
    tag = "FiSkipForward"


class FiSlack(rx.Component):
    library = "react-icons/fi"
    tag = "FiSlack"


class FiSlash(rx.Component):
    library = "react-icons/fi"
    tag = "FiSlash"


class FiSliders(rx.Component):
    library = "react-icons/fi"
    tag = "FiSliders"


class FiSmartphone(rx.Component):
    library = "react-icons/fi"
    tag = "FiSmartphone"


class FiSmile(rx.Component):
    library = "react-icons/fi"
    tag = "FiSmile"


class FiSpeaker(rx.Component):
    library = "react-icons/fi"
    tag = "FiSpeaker"


class FiSquare(rx.Component):
    library = "react-icons/fi"
    tag = "FiSquare"


class FiStar(rx.Component):
    library = "react-icons/fi"
    tag = "FiStar"


class FiStopCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiStopCircle"


class FiSun(rx.Component):
    library = "react-icons/fi"
    tag = "FiSun"


class FiSunrise(rx.Component):
    library = "react-icons/fi"
    tag = "FiSunrise"


class FiSunset(rx.Component):
    library = "react-icons/fi"
    tag = "FiSunset"


class FiTablet(rx.Component):
    library = "react-icons/fi"
    tag = "FiTablet"


class FiTag(rx.Component):
    library = "react-icons/fi"
    tag = "FiTag"


class FiTarget(rx.Component):
    library = "react-icons/fi"
    tag = "FiTarget"


class FiTerminal(rx.Component):
    library = "react-icons/fi"
    tag = "FiTerminal"


class FiThermometer(rx.Component):
    library = "react-icons/fi"
    tag = "FiThermometer"


class FiThumbsDown(rx.Component):
    library = "react-icons/fi"
    tag = "FiThumbsDown"


class FiThumbsUp(rx.Component):
    library = "react-icons/fi"
    tag = "FiThumbsUp"


class FiToggleLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiToggleLeft"


class FiToggleRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiToggleRight"


class FiTool(rx.Component):
    library = "react-icons/fi"
    tag = "FiTool"


class FiTrash2(rx.Component):
    library = "react-icons/fi"
    tag = "FiTrash2"


class FiTrash(rx.Component):
    library = "react-icons/fi"
    tag = "FiTrash"


class FiTrello(rx.Component):
    library = "react-icons/fi"
    tag = "FiTrello"


class FiTrendingDown(rx.Component):
    library = "react-icons/fi"
    tag = "FiTrendingDown"


class FiTrendingUp(rx.Component):
    library = "react-icons/fi"
    tag = "FiTrendingUp"


class FiTriangle(rx.Component):
    library = "react-icons/fi"
    tag = "FiTriangle"


class FiTruck(rx.Component):
    library = "react-icons/fi"
    tag = "FiTruck"


class FiTv(rx.Component):
    library = "react-icons/fi"
    tag = "FiTv"


class FiTwitch(rx.Component):
    library = "react-icons/fi"
    tag = "FiTwitch"


class FiTwitter(rx.Component):
    library = "react-icons/fi"
    tag = "FiTwitter"


class FiType(rx.Component):
    library = "react-icons/fi"
    tag = "FiType"


class FiUmbrella(rx.Component):
    library = "react-icons/fi"
    tag = "FiUmbrella"


class FiUnderline(rx.Component):
    library = "react-icons/fi"
    tag = "FiUnderline"


class FiUnlock(rx.Component):
    library = "react-icons/fi"
    tag = "FiUnlock"


class FiUploadCloud(rx.Component):
    library = "react-icons/fi"
    tag = "FiUploadCloud"


class FiUpload(rx.Component):
    library = "react-icons/fi"
    tag = "FiUpload"


class FiUserCheck(rx.Component):
    library = "react-icons/fi"
    tag = "FiUserCheck"


class FiUserMinus(rx.Component):
    library = "react-icons/fi"
    tag = "FiUserMinus"


class FiUserPlus(rx.Component):
    library = "react-icons/fi"
    tag = "FiUserPlus"


class FiUserX(rx.Component):
    library = "react-icons/fi"
    tag = "FiUserX"


class FiUser(rx.Component):
    library = "react-icons/fi"
    tag = "FiUser"


class FiUsers(rx.Component):
    library = "react-icons/fi"
    tag = "FiUsers"


class FiVideoOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiVideoOff"


class FiVideo(rx.Component):
    library = "react-icons/fi"
    tag = "FiVideo"


class FiVoicemail(rx.Component):
    library = "react-icons/fi"
    tag = "FiVoicemail"


class FiVolume1(rx.Component):
    library = "react-icons/fi"
    tag = "FiVolume1"


class FiVolume2(rx.Component):
    library = "react-icons/fi"
    tag = "FiVolume2"


class FiVolumeX(rx.Component):
    library = "react-icons/fi"
    tag = "FiVolumeX"


class FiVolume(rx.Component):
    library = "react-icons/fi"
    tag = "FiVolume"


class FiWatch(rx.Component):
    library = "react-icons/fi"
    tag = "FiWatch"


class FiWifiOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiWifiOff"


class FiWifi(rx.Component):
    library = "react-icons/fi"
    tag = "FiWifi"


class FiWind(rx.Component):
    library = "react-icons/fi"
    tag = "FiWind"


class FiXCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiXCircle"


class FiXOctagon(rx.Component):
    library = "react-icons/fi"
    tag = "FiXOctagon"


class FiXSquare(rx.Component):
    library = "react-icons/fi"
    tag = "FiXSquare"


class FiX(rx.Component):
    library = "react-icons/fi"
    tag = "FiX"


class FiYoutube(rx.Component):
    library = "react-icons/fi"
    tag = "FiYoutube"


class FiZapOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiZapOff"


class FiZap(rx.Component):
    library = "react-icons/fi"
    tag = "FiZap"


class FiZoomIn(rx.Component):
    library = "react-icons/fi"
    tag = "FiZoomIn"


class FiZoomOut(rx.Component):
    library = "react-icons/fi"
    tag = "FiZoomOut"





import reflex as rx

class FcAbout(rx.Component):
    library = "react-icons/fc"
    tag = "FcAbout"


class FcAcceptDatabase(rx.Component):
    library = "react-icons/fc"
    tag = "FcAcceptDatabase"


class FcAddColumn(rx.Component):
    library = "react-icons/fc"
    tag = "FcAddColumn"


class FcAddDatabase(rx.Component):
    library = "react-icons/fc"
    tag = "FcAddDatabase"


class FcAddImage(rx.Component):
    library = "react-icons/fc"
    tag = "FcAddImage"


class FcAddRow(rx.Component):
    library = "react-icons/fc"
    tag = "FcAddRow"


class FcAddressBook(rx.Component):
    library = "react-icons/fc"
    tag = "FcAddressBook"


class FcAdvance(rx.Component):
    library = "react-icons/fc"
    tag = "FcAdvance"


class FcAdvertising(rx.Component):
    library = "react-icons/fc"
    tag = "FcAdvertising"


class FcAlarmClock(rx.Component):
    library = "react-icons/fc"
    tag = "FcAlarmClock"


class FcAlphabeticalSortingAz(rx.Component):
    library = "react-icons/fc"
    tag = "FcAlphabeticalSortingAz"


class FcAlphabeticalSortingZa(rx.Component):
    library = "react-icons/fc"
    tag = "FcAlphabeticalSortingZa"


class FcAndroidOs(rx.Component):
    library = "react-icons/fc"
    tag = "FcAndroidOs"


class FcAnswers(rx.Component):
    library = "react-icons/fc"
    tag = "FcAnswers"


class FcApproval(rx.Component):
    library = "react-icons/fc"
    tag = "FcApproval"


class FcApprove(rx.Component):
    library = "react-icons/fc"
    tag = "FcApprove"


class FcAreaChart(rx.Component):
    library = "react-icons/fc"
    tag = "FcAreaChart"


class FcAssistant(rx.Component):
    library = "react-icons/fc"
    tag = "FcAssistant"


class FcAudioFile(rx.Component):
    library = "react-icons/fc"
    tag = "FcAudioFile"


class FcAutomatic(rx.Component):
    library = "react-icons/fc"
    tag = "FcAutomatic"


class FcAutomotive(rx.Component):
    library = "react-icons/fc"
    tag = "FcAutomotive"


class FcBadDecision(rx.Component):
    library = "react-icons/fc"
    tag = "FcBadDecision"


class FcBarChart(rx.Component):
    library = "react-icons/fc"
    tag = "FcBarChart"


class FcBbc(rx.Component):
    library = "react-icons/fc"
    tag = "FcBbc"


class FcBearish(rx.Component):
    library = "react-icons/fc"
    tag = "FcBearish"


class FcBinoculars(rx.Component):
    library = "react-icons/fc"
    tag = "FcBinoculars"


class FcBiohazard(rx.Component):
    library = "react-icons/fc"
    tag = "FcBiohazard"


class FcBiomass(rx.Component):
    library = "react-icons/fc"
    tag = "FcBiomass"


class FcBiotech(rx.Component):
    library = "react-icons/fc"
    tag = "FcBiotech"


class FcBookmark(rx.Component):
    library = "react-icons/fc"
    tag = "FcBookmark"


class FcBriefcase(rx.Component):
    library = "react-icons/fc"
    tag = "FcBriefcase"


class FcBrokenLink(rx.Component):
    library = "react-icons/fc"
    tag = "FcBrokenLink"


class FcBullish(rx.Component):
    library = "react-icons/fc"
    tag = "FcBullish"


class FcBusinessContact(rx.Component):
    library = "react-icons/fc"
    tag = "FcBusinessContact"


class FcBusiness(rx.Component):
    library = "react-icons/fc"
    tag = "FcBusiness"


class FcBusinessman(rx.Component):
    library = "react-icons/fc"
    tag = "FcBusinessman"


class FcBusinesswoman(rx.Component):
    library = "react-icons/fc"
    tag = "FcBusinesswoman"


class FcButtingIn(rx.Component):
    library = "react-icons/fc"
    tag = "FcButtingIn"


class FcCableRelease(rx.Component):
    library = "react-icons/fc"
    tag = "FcCableRelease"


class FcCalculator(rx.Component):
    library = "react-icons/fc"
    tag = "FcCalculator"


class FcCalendar(rx.Component):
    library = "react-icons/fc"
    tag = "FcCalendar"


class FcCallTransfer(rx.Component):
    library = "react-icons/fc"
    tag = "FcCallTransfer"


class FcCallback(rx.Component):
    library = "react-icons/fc"
    tag = "FcCallback"


class FcCamcorderPro(rx.Component):
    library = "react-icons/fc"
    tag = "FcCamcorderPro"


class FcCamcorder(rx.Component):
    library = "react-icons/fc"
    tag = "FcCamcorder"


class FcCameraAddon(rx.Component):
    library = "react-icons/fc"
    tag = "FcCameraAddon"


class FcCameraIdentification(rx.Component):
    library = "react-icons/fc"
    tag = "FcCameraIdentification"


class FcCamera(rx.Component):
    library = "react-icons/fc"
    tag = "FcCamera"


class FcCancel(rx.Component):
    library = "react-icons/fc"
    tag = "FcCancel"


class FcCandleSticks(rx.Component):
    library = "react-icons/fc"
    tag = "FcCandleSticks"


class FcCapacitor(rx.Component):
    library = "react-icons/fc"
    tag = "FcCapacitor"


class FcCdLogo(rx.Component):
    library = "react-icons/fc"
    tag = "FcCdLogo"


class FcCellPhone(rx.Component):
    library = "react-icons/fc"
    tag = "FcCellPhone"


class FcChargeBattery(rx.Component):
    library = "react-icons/fc"
    tag = "FcChargeBattery"


class FcCheckmark(rx.Component):
    library = "react-icons/fc"
    tag = "FcCheckmark"


class FcCircuit(rx.Component):
    library = "react-icons/fc"
    tag = "FcCircuit"


class FcClapperboard(rx.Component):
    library = "react-icons/fc"
    tag = "FcClapperboard"


class FcClearFilters(rx.Component):
    library = "react-icons/fc"
    tag = "FcClearFilters"


class FcClock(rx.Component):
    library = "react-icons/fc"
    tag = "FcClock"


class FcCloseUpMode(rx.Component):
    library = "react-icons/fc"
    tag = "FcCloseUpMode"


class FcCloth(rx.Component):
    library = "react-icons/fc"
    tag = "FcCloth"


class FcCollaboration(rx.Component):
    library = "react-icons/fc"
    tag = "FcCollaboration"


class FcCollapse(rx.Component):
    library = "react-icons/fc"
    tag = "FcCollapse"


class FcCollect(rx.Component):
    library = "react-icons/fc"
    tag = "FcCollect"


class FcComboChart(rx.Component):
    library = "react-icons/fc"
    tag = "FcComboChart"


class FcCommandLine(rx.Component):
    library = "react-icons/fc"
    tag = "FcCommandLine"


class FcComments(rx.Component):
    library = "react-icons/fc"
    tag = "FcComments"


class FcCompactCamera(rx.Component):
    library = "react-icons/fc"
    tag = "FcCompactCamera"


class FcConferenceCall(rx.Component):
    library = "react-icons/fc"
    tag = "FcConferenceCall"


class FcContacts(rx.Component):
    library = "react-icons/fc"
    tag = "FcContacts"


class FcCopyleft(rx.Component):
    library = "react-icons/fc"
    tag = "FcCopyleft"


class FcCopyright(rx.Component):
    library = "react-icons/fc"
    tag = "FcCopyright"


class FcCrystalOscillator(rx.Component):
    library = "react-icons/fc"
    tag = "FcCrystalOscillator"


class FcCurrencyExchange(rx.Component):
    library = "react-icons/fc"
    tag = "FcCurrencyExchange"


class FcCursor(rx.Component):
    library = "react-icons/fc"
    tag = "FcCursor"


class FcCustomerSupport(rx.Component):
    library = "react-icons/fc"
    tag = "FcCustomerSupport"


class FcDam(rx.Component):
    library = "react-icons/fc"
    tag = "FcDam"


class FcDataBackup(rx.Component):
    library = "react-icons/fc"
    tag = "FcDataBackup"


class FcDataConfiguration(rx.Component):
    library = "react-icons/fc"
    tag = "FcDataConfiguration"


class FcDataEncryption(rx.Component):
    library = "react-icons/fc"
    tag = "FcDataEncryption"


class FcDataProtection(rx.Component):
    library = "react-icons/fc"
    tag = "FcDataProtection"


class FcDataRecovery(rx.Component):
    library = "react-icons/fc"
    tag = "FcDataRecovery"


class FcDataSheet(rx.Component):
    library = "react-icons/fc"
    tag = "FcDataSheet"


class FcDatabase(rx.Component):
    library = "react-icons/fc"
    tag = "FcDatabase"


class FcDebian(rx.Component):
    library = "react-icons/fc"
    tag = "FcDebian"


class FcDebt(rx.Component):
    library = "react-icons/fc"
    tag = "FcDebt"


class FcDecision(rx.Component):
    library = "react-icons/fc"
    tag = "FcDecision"


class FcDeleteColumn(rx.Component):
    library = "react-icons/fc"
    tag = "FcDeleteColumn"


class FcDeleteDatabase(rx.Component):
    library = "react-icons/fc"
    tag = "FcDeleteDatabase"


class FcDeleteRow(rx.Component):
    library = "react-icons/fc"
    tag = "FcDeleteRow"


class FcDepartment(rx.Component):
    library = "react-icons/fc"
    tag = "FcDepartment"


class FcDeployment(rx.Component):
    library = "react-icons/fc"
    tag = "FcDeployment"


class FcDiploma1(rx.Component):
    library = "react-icons/fc"
    tag = "FcDiploma1"


class FcDiploma2(rx.Component):
    library = "react-icons/fc"
    tag = "FcDiploma2"


class FcDisapprove(rx.Component):
    library = "react-icons/fc"
    tag = "FcDisapprove"


class FcDisclaimer(rx.Component):
    library = "react-icons/fc"
    tag = "FcDisclaimer"


class FcDislike(rx.Component):
    library = "react-icons/fc"
    tag = "FcDislike"


class FcDisplay(rx.Component):
    library = "react-icons/fc"
    tag = "FcDisplay"


class FcDoNotInhale(rx.Component):
    library = "react-icons/fc"
    tag = "FcDoNotInhale"


class FcDoNotInsert(rx.Component):
    library = "react-icons/fc"
    tag = "FcDoNotInsert"


class FcDoNotMix(rx.Component):
    library = "react-icons/fc"
    tag = "FcDoNotMix"


class FcDocument(rx.Component):
    library = "react-icons/fc"
    tag = "FcDocument"


class FcDonate(rx.Component):
    library = "react-icons/fc"
    tag = "FcDonate"


class FcDoughnutChart(rx.Component):
    library = "react-icons/fc"
    tag = "FcDoughnutChart"


class FcDownLeft(rx.Component):
    library = "react-icons/fc"
    tag = "FcDownLeft"


class FcDownRight(rx.Component):
    library = "react-icons/fc"
    tag = "FcDownRight"


class FcDown(rx.Component):
    library = "react-icons/fc"
    tag = "FcDown"


class FcDownload(rx.Component):
    library = "react-icons/fc"
    tag = "FcDownload"


class FcDribbble(rx.Component):
    library = "react-icons/fc"
    tag = "FcDribbble"


class FcDvdLogo(rx.Component):
    library = "react-icons/fc"
    tag = "FcDvdLogo"


class FcEditImage(rx.Component):
    library = "react-icons/fc"
    tag = "FcEditImage"


class FcElectricalSensor(rx.Component):
    library = "react-icons/fc"
    tag = "FcElectricalSensor"


class FcElectricalThreshold(rx.Component):
    library = "react-icons/fc"
    tag = "FcElectricalThreshold"


class FcElectricity(rx.Component):
    library = "react-icons/fc"
    tag = "FcElectricity"


class FcElectroDevices(rx.Component):
    library = "react-icons/fc"
    tag = "FcElectroDevices"


class FcElectronics(rx.Component):
    library = "react-icons/fc"
    tag = "FcElectronics"


class FcEmptyBattery(rx.Component):
    library = "react-icons/fc"
    tag = "FcEmptyBattery"


class FcEmptyFilter(rx.Component):
    library = "react-icons/fc"
    tag = "FcEmptyFilter"


class FcEmptyTrash(rx.Component):
    library = "react-icons/fc"
    tag = "FcEmptyTrash"


class FcEndCall(rx.Component):
    library = "react-icons/fc"
    tag = "FcEndCall"


class FcEngineering(rx.Component):
    library = "react-icons/fc"
    tag = "FcEngineering"


class FcEnteringHeavenAlive(rx.Component):
    library = "react-icons/fc"
    tag = "FcEnteringHeavenAlive"


class FcExpand(rx.Component):
    library = "react-icons/fc"
    tag = "FcExpand"


class FcExpired(rx.Component):
    library = "react-icons/fc"
    tag = "FcExpired"


class FcExport(rx.Component):
    library = "react-icons/fc"
    tag = "FcExport"


class FcExternal(rx.Component):
    library = "react-icons/fc"
    tag = "FcExternal"


class FcFactoryBreakdown(rx.Component):
    library = "react-icons/fc"
    tag = "FcFactoryBreakdown"


class FcFactory(rx.Component):
    library = "react-icons/fc"
    tag = "FcFactory"


class FcFaq(rx.Component):
    library = "react-icons/fc"
    tag = "FcFaq"


class FcFeedIn(rx.Component):
    library = "react-icons/fc"
    tag = "FcFeedIn"


class FcFeedback(rx.Component):
    library = "react-icons/fc"
    tag = "FcFeedback"


class FcFile(rx.Component):
    library = "react-icons/fc"
    tag = "FcFile"


class FcFilingCabinet(rx.Component):
    library = "react-icons/fc"
    tag = "FcFilingCabinet"


class FcFilledFilter(rx.Component):
    library = "react-icons/fc"
    tag = "FcFilledFilter"


class FcFilmReel(rx.Component):
    library = "react-icons/fc"
    tag = "FcFilmReel"


class FcFilm(rx.Component):
    library = "react-icons/fc"
    tag = "FcFilm"


class FcFinePrint(rx.Component):
    library = "react-icons/fc"
    tag = "FcFinePrint"


class FcFlashAuto(rx.Component):
    library = "react-icons/fc"
    tag = "FcFlashAuto"


class FcFlashOff(rx.Component):
    library = "react-icons/fc"
    tag = "FcFlashOff"


class FcFlashOn(rx.Component):
    library = "react-icons/fc"
    tag = "FcFlashOn"


class FcFlowChart(rx.Component):
    library = "react-icons/fc"
    tag = "FcFlowChart"


class FcFolder(rx.Component):
    library = "react-icons/fc"
    tag = "FcFolder"


class FcFrame(rx.Component):
    library = "react-icons/fc"
    tag = "FcFrame"


class FcFullBattery(rx.Component):
    library = "react-icons/fc"
    tag = "FcFullBattery"


class FcFullTrash(rx.Component):
    library = "react-icons/fc"
    tag = "FcFullTrash"


class FcGallery(rx.Component):
    library = "react-icons/fc"
    tag = "FcGallery"


class FcGenealogy(rx.Component):
    library = "react-icons/fc"
    tag = "FcGenealogy"


class FcGenericSortingAsc(rx.Component):
    library = "react-icons/fc"
    tag = "FcGenericSortingAsc"


class FcGenericSortingDesc(rx.Component):
    library = "react-icons/fc"
    tag = "FcGenericSortingDesc"


class FcGlobe(rx.Component):
    library = "react-icons/fc"
    tag = "FcGlobe"


class FcGoodDecision(rx.Component):
    library = "react-icons/fc"
    tag = "FcGoodDecision"


class FcGoogle(rx.Component):
    library = "react-icons/fc"
    tag = "FcGoogle"


class FcGraduationCap(rx.Component):
    library = "react-icons/fc"
    tag = "FcGraduationCap"


class FcGrid(rx.Component):
    library = "react-icons/fc"
    tag = "FcGrid"


class FcHeadset(rx.Component):
    library = "react-icons/fc"
    tag = "FcHeadset"


class FcHeatMap(rx.Component):
    library = "react-icons/fc"
    tag = "FcHeatMap"


class FcHighBattery(rx.Component):
    library = "react-icons/fc"
    tag = "FcHighBattery"


class FcHighPriority(rx.Component):
    library = "react-icons/fc"
    tag = "FcHighPriority"


class FcHome(rx.Component):
    library = "react-icons/fc"
    tag = "FcHome"


class FcIcons8Cup(rx.Component):
    library = "react-icons/fc"
    tag = "FcIcons8Cup"


class FcIdea(rx.Component):
    library = "react-icons/fc"
    tag = "FcIdea"


class FcImageFile(rx.Component):
    library = "react-icons/fc"
    tag = "FcImageFile"


class FcImport(rx.Component):
    library = "react-icons/fc"
    tag = "FcImport"


class FcInTransit(rx.Component):
    library = "react-icons/fc"
    tag = "FcInTransit"


class FcInfo(rx.Component):
    library = "react-icons/fc"
    tag = "FcInfo"


class FcInspection(rx.Component):
    library = "react-icons/fc"
    tag = "FcInspection"


class FcIntegratedWebcam(rx.Component):
    library = "react-icons/fc"
    tag = "FcIntegratedWebcam"


class FcInternal(rx.Component):
    library = "react-icons/fc"
    tag = "FcInternal"


class FcInvite(rx.Component):
    library = "react-icons/fc"
    tag = "FcInvite"


class FcIpad(rx.Component):
    library = "react-icons/fc"
    tag = "FcIpad"


class FcIphone(rx.Component):
    library = "react-icons/fc"
    tag = "FcIphone"


class FcKey(rx.Component):
    library = "react-icons/fc"
    tag = "FcKey"


class FcKindle(rx.Component):
    library = "react-icons/fc"
    tag = "FcKindle"


class FcLandscape(rx.Component):
    library = "react-icons/fc"
    tag = "FcLandscape"


class FcLeave(rx.Component):
    library = "react-icons/fc"
    tag = "FcLeave"


class FcLeftDown(rx.Component):
    library = "react-icons/fc"
    tag = "FcLeftDown"


class FcLeftDown2(rx.Component):
    library = "react-icons/fc"
    tag = "FcLeftDown2"


class FcLeftUp(rx.Component):
    library = "react-icons/fc"
    tag = "FcLeftUp"


class FcLeftUp2(rx.Component):
    library = "react-icons/fc"
    tag = "FcLeftUp2"


class FcLeft(rx.Component):
    library = "react-icons/fc"
    tag = "FcLeft"


class FcLibrary(rx.Component):
    library = "react-icons/fc"
    tag = "FcLibrary"


class FcLightAtTheEndOfTunnel(rx.Component):
    library = "react-icons/fc"
    tag = "FcLightAtTheEndOfTunnel"


class FcLikePlaceholder(rx.Component):
    library = "react-icons/fc"
    tag = "FcLikePlaceholder"


class FcLike(rx.Component):
    library = "react-icons/fc"
    tag = "FcLike"


class FcLineChart(rx.Component):
    library = "react-icons/fc"
    tag = "FcLineChart"


class FcLink(rx.Component):
    library = "react-icons/fc"
    tag = "FcLink"


class FcLinux(rx.Component):
    library = "react-icons/fc"
    tag = "FcLinux"


class FcList(rx.Component):
    library = "react-icons/fc"
    tag = "FcList"


class FcLockLandscape(rx.Component):
    library = "react-icons/fc"
    tag = "FcLockLandscape"


class FcLockPortrait(rx.Component):
    library = "react-icons/fc"
    tag = "FcLockPortrait"


class FcLock(rx.Component):
    library = "react-icons/fc"
    tag = "FcLock"


class FcLowBattery(rx.Component):
    library = "react-icons/fc"
    tag = "FcLowBattery"


class FcLowPriority(rx.Component):
    library = "react-icons/fc"
    tag = "FcLowPriority"


class FcMakeDecision(rx.Component):
    library = "react-icons/fc"
    tag = "FcMakeDecision"


class FcManager(rx.Component):
    library = "react-icons/fc"
    tag = "FcManager"


class FcMediumPriority(rx.Component):
    library = "react-icons/fc"
    tag = "FcMediumPriority"


class FcMenu(rx.Component):
    library = "react-icons/fc"
    tag = "FcMenu"


class FcMiddleBattery(rx.Component):
    library = "react-icons/fc"
    tag = "FcMiddleBattery"


class FcMindMap(rx.Component):
    library = "react-icons/fc"
    tag = "FcMindMap"


class FcMinus(rx.Component):
    library = "react-icons/fc"
    tag = "FcMinus"


class FcMissedCall(rx.Component):
    library = "react-icons/fc"
    tag = "FcMissedCall"


class FcMms(rx.Component):
    library = "react-icons/fc"
    tag = "FcMms"


class FcMoneyTransfer(rx.Component):
    library = "react-icons/fc"
    tag = "FcMoneyTransfer"


class FcMultipleCameras(rx.Component):
    library = "react-icons/fc"
    tag = "FcMultipleCameras"


class FcMultipleDevices(rx.Component):
    library = "react-icons/fc"
    tag = "FcMultipleDevices"


class FcMultipleInputs(rx.Component):
    library = "react-icons/fc"
    tag = "FcMultipleInputs"


class FcMultipleSmartphones(rx.Component):
    library = "react-icons/fc"
    tag = "FcMultipleSmartphones"


class FcMusic(rx.Component):
    library = "react-icons/fc"
    tag = "FcMusic"


class FcNegativeDynamic(rx.Component):
    library = "react-icons/fc"
    tag = "FcNegativeDynamic"


class FcNeutralDecision(rx.Component):
    library = "react-icons/fc"
    tag = "FcNeutralDecision"


class FcNeutralTrading(rx.Component):
    library = "react-icons/fc"
    tag = "FcNeutralTrading"


class FcNews(rx.Component):
    library = "react-icons/fc"
    tag = "FcNews"


class FcNext(rx.Component):
    library = "react-icons/fc"
    tag = "FcNext"


class FcNfcSign(rx.Component):
    library = "react-icons/fc"
    tag = "FcNfcSign"


class FcNightLandscape(rx.Component):
    library = "react-icons/fc"
    tag = "FcNightLandscape"


class FcNightPortrait(rx.Component):
    library = "react-icons/fc"
    tag = "FcNightPortrait"


class FcNoIdea(rx.Component):
    library = "react-icons/fc"
    tag = "FcNoIdea"


class FcNoVideo(rx.Component):
    library = "react-icons/fc"
    tag = "FcNoVideo"


class FcNook(rx.Component):
    library = "react-icons/fc"
    tag = "FcNook"


class FcNumericalSorting12(rx.Component):
    library = "react-icons/fc"
    tag = "FcNumericalSorting12"


class FcNumericalSorting21(rx.Component):
    library = "react-icons/fc"
    tag = "FcNumericalSorting21"


class FcOk(rx.Component):
    library = "react-icons/fc"
    tag = "FcOk"


class FcOldTimeCamera(rx.Component):
    library = "react-icons/fc"
    tag = "FcOldTimeCamera"


class FcOnlineSupport(rx.Component):
    library = "react-icons/fc"
    tag = "FcOnlineSupport"


class FcOpenedFolder(rx.Component):
    library = "react-icons/fc"
    tag = "FcOpenedFolder"


class FcOrgUnit(rx.Component):
    library = "react-icons/fc"
    tag = "FcOrgUnit"


class FcOrganization(rx.Component):
    library = "react-icons/fc"
    tag = "FcOrganization"


class FcOvertime(rx.Component):
    library = "react-icons/fc"
    tag = "FcOvertime"


class FcPackage(rx.Component):
    library = "react-icons/fc"
    tag = "FcPackage"


class FcPaid(rx.Component):
    library = "react-icons/fc"
    tag = "FcPaid"


class FcPanorama(rx.Component):
    library = "react-icons/fc"
    tag = "FcPanorama"


class FcParallelTasks(rx.Component):
    library = "react-icons/fc"
    tag = "FcParallelTasks"


class FcPhoneAndroid(rx.Component):
    library = "react-icons/fc"
    tag = "FcPhoneAndroid"


class FcPhone(rx.Component):
    library = "react-icons/fc"
    tag = "FcPhone"


class FcPhotoReel(rx.Component):
    library = "react-icons/fc"
    tag = "FcPhotoReel"


class FcPicture(rx.Component):
    library = "react-icons/fc"
    tag = "FcPicture"


class FcPieChart(rx.Component):
    library = "react-icons/fc"
    tag = "FcPieChart"


class FcPlanner(rx.Component):
    library = "react-icons/fc"
    tag = "FcPlanner"


class FcPlus(rx.Component):
    library = "react-icons/fc"
    tag = "FcPlus"


class FcPodiumWithAudience(rx.Component):
    library = "react-icons/fc"
    tag = "FcPodiumWithAudience"


class FcPodiumWithSpeaker(rx.Component):
    library = "react-icons/fc"
    tag = "FcPodiumWithSpeaker"


class FcPodiumWithoutSpeaker(rx.Component):
    library = "react-icons/fc"
    tag = "FcPodiumWithoutSpeaker"


class FcPortraitMode(rx.Component):
    library = "react-icons/fc"
    tag = "FcPortraitMode"


class FcPositiveDynamic(rx.Component):
    library = "react-icons/fc"
    tag = "FcPositiveDynamic"


class FcPrevious(rx.Component):
    library = "react-icons/fc"
    tag = "FcPrevious"


class FcPrint(rx.Component):
    library = "react-icons/fc"
    tag = "FcPrint"


class FcPrivacy(rx.Component):
    library = "react-icons/fc"
    tag = "FcPrivacy"


class FcProcess(rx.Component):
    library = "react-icons/fc"
    tag = "FcProcess"


class FcPuzzle(rx.Component):
    library = "react-icons/fc"
    tag = "FcPuzzle"


class FcQuestions(rx.Component):
    library = "react-icons/fc"
    tag = "FcQuestions"


class FcRadarPlot(rx.Component):
    library = "react-icons/fc"
    tag = "FcRadarPlot"


class FcRating(rx.Component):
    library = "react-icons/fc"
    tag = "FcRating"


class FcRatings(rx.Component):
    library = "react-icons/fc"
    tag = "FcRatings"


class FcReadingEbook(rx.Component):
    library = "react-icons/fc"
    tag = "FcReadingEbook"


class FcReading(rx.Component):
    library = "react-icons/fc"
    tag = "FcReading"


class FcReddit(rx.Component):
    library = "react-icons/fc"
    tag = "FcReddit"


class FcRedo(rx.Component):
    library = "react-icons/fc"
    tag = "FcRedo"


class FcRefresh(rx.Component):
    library = "react-icons/fc"
    tag = "FcRefresh"


class FcRegisteredTrademark(rx.Component):
    library = "react-icons/fc"
    tag = "FcRegisteredTrademark"


class FcRemoveImage(rx.Component):
    library = "react-icons/fc"
    tag = "FcRemoveImage"


class FcReuse(rx.Component):
    library = "react-icons/fc"
    tag = "FcReuse"


class FcRightDown(rx.Component):
    library = "react-icons/fc"
    tag = "FcRightDown"


class FcRightDown2(rx.Component):
    library = "react-icons/fc"
    tag = "FcRightDown2"


class FcRightUp(rx.Component):
    library = "react-icons/fc"
    tag = "FcRightUp"


class FcRightUp2(rx.Component):
    library = "react-icons/fc"
    tag = "FcRightUp2"


class FcRight(rx.Component):
    library = "react-icons/fc"
    tag = "FcRight"


class FcRotateCamera(rx.Component):
    library = "react-icons/fc"
    tag = "FcRotateCamera"


class FcRotateToLandscape(rx.Component):
    library = "react-icons/fc"
    tag = "FcRotateToLandscape"


class FcRotateToPortrait(rx.Component):
    library = "react-icons/fc"
    tag = "FcRotateToPortrait"


class FcRuler(rx.Component):
    library = "react-icons/fc"
    tag = "FcRuler"


class FcRules(rx.Component):
    library = "react-icons/fc"
    tag = "FcRules"


class FcSafe(rx.Component):
    library = "react-icons/fc"
    tag = "FcSafe"


class FcSalesPerformance(rx.Component):
    library = "react-icons/fc"
    tag = "FcSalesPerformance"


class FcScatterPlot(rx.Component):
    library = "react-icons/fc"
    tag = "FcScatterPlot"


class FcSearch(rx.Component):
    library = "react-icons/fc"
    tag = "FcSearch"


class FcSelfServiceKiosk(rx.Component):
    library = "react-icons/fc"
    tag = "FcSelfServiceKiosk"


class FcSelfie(rx.Component):
    library = "react-icons/fc"
    tag = "FcSelfie"


class FcSerialTasks(rx.Component):
    library = "react-icons/fc"
    tag = "FcSerialTasks"


class FcServiceMark(rx.Component):
    library = "react-icons/fc"
    tag = "FcServiceMark"


class FcServices(rx.Component):
    library = "react-icons/fc"
    tag = "FcServices"


class FcSettings(rx.Component):
    library = "react-icons/fc"
    tag = "FcSettings"


class FcShare(rx.Component):
    library = "react-icons/fc"
    tag = "FcShare"


class FcShipped(rx.Component):
    library = "react-icons/fc"
    tag = "FcShipped"


class FcShop(rx.Component):
    library = "react-icons/fc"
    tag = "FcShop"


class FcSignature(rx.Component):
    library = "react-icons/fc"
    tag = "FcSignature"


class FcSimCardChip(rx.Component):
    library = "react-icons/fc"
    tag = "FcSimCardChip"


class FcSimCard(rx.Component):
    library = "react-icons/fc"
    tag = "FcSimCard"


class FcSlrBackSide(rx.Component):
    library = "react-icons/fc"
    tag = "FcSlrBackSide"


class FcSmartphoneTablet(rx.Component):
    library = "react-icons/fc"
    tag = "FcSmartphoneTablet"


class FcSms(rx.Component):
    library = "react-icons/fc"
    tag = "FcSms"


class FcSoundRecordingCopyright(rx.Component):
    library = "react-icons/fc"
    tag = "FcSoundRecordingCopyright"


class FcSpeaker(rx.Component):
    library = "react-icons/fc"
    tag = "FcSpeaker"


class FcSportsMode(rx.Component):
    library = "react-icons/fc"
    tag = "FcSportsMode"


class FcStackOfPhotos(rx.Component):
    library = "react-icons/fc"
    tag = "FcStackOfPhotos"


class FcStart(rx.Component):
    library = "react-icons/fc"
    tag = "FcStart"


class FcStatistics(rx.Component):
    library = "react-icons/fc"
    tag = "FcStatistics"


class FcSteam(rx.Component):
    library = "react-icons/fc"
    tag = "FcSteam"


class FcStumbleupon(rx.Component):
    library = "react-icons/fc"
    tag = "FcStumbleupon"


class FcSupport(rx.Component):
    library = "react-icons/fc"
    tag = "FcSupport"


class FcSurvey(rx.Component):
    library = "react-icons/fc"
    tag = "FcSurvey"


class FcSwitchCamera(rx.Component):
    library = "react-icons/fc"
    tag = "FcSwitchCamera"


class FcSynchronize(rx.Component):
    library = "react-icons/fc"
    tag = "FcSynchronize"


class FcTabletAndroid(rx.Component):
    library = "react-icons/fc"
    tag = "FcTabletAndroid"


class FcTemplate(rx.Component):
    library = "react-icons/fc"
    tag = "FcTemplate"


class FcTimeline(rx.Component):
    library = "react-icons/fc"
    tag = "FcTimeline"


class FcTodoList(rx.Component):
    library = "react-icons/fc"
    tag = "FcTodoList"


class FcTouchscreenSmartphone(rx.Component):
    library = "react-icons/fc"
    tag = "FcTouchscreenSmartphone"


class FcTrademark(rx.Component):
    library = "react-icons/fc"
    tag = "FcTrademark"


class FcTreeStructure(rx.Component):
    library = "react-icons/fc"
    tag = "FcTreeStructure"


class FcTwoSmartphones(rx.Component):
    library = "react-icons/fc"
    tag = "FcTwoSmartphones"


class FcUndo(rx.Component):
    library = "react-icons/fc"
    tag = "FcUndo"


class FcUnlock(rx.Component):
    library = "react-icons/fc"
    tag = "FcUnlock"


class FcUpLeft(rx.Component):
    library = "react-icons/fc"
    tag = "FcUpLeft"


class FcUpRight(rx.Component):
    library = "react-icons/fc"
    tag = "FcUpRight"


class FcUp(rx.Component):
    library = "react-icons/fc"
    tag = "FcUp"


class FcUpload(rx.Component):
    library = "react-icons/fc"
    tag = "FcUpload"


class FcUsb(rx.Component):
    library = "react-icons/fc"
    tag = "FcUsb"


class FcVideoCall(rx.Component):
    library = "react-icons/fc"
    tag = "FcVideoCall"


class FcVideoFile(rx.Component):
    library = "react-icons/fc"
    tag = "FcVideoFile"


class FcVideoProjector(rx.Component):
    library = "react-icons/fc"
    tag = "FcVideoProjector"


class FcViewDetails(rx.Component):
    library = "react-icons/fc"
    tag = "FcViewDetails"


class FcVip(rx.Component):
    library = "react-icons/fc"
    tag = "FcVip"


class FcVlc(rx.Component):
    library = "react-icons/fc"
    tag = "FcVlc"


class FcVoicePresentation(rx.Component):
    library = "react-icons/fc"
    tag = "FcVoicePresentation"


class FcVoicemail(rx.Component):
    library = "react-icons/fc"
    tag = "FcVoicemail"


class FcWebcam(rx.Component):
    library = "react-icons/fc"
    tag = "FcWebcam"


class FcWiFiLogo(rx.Component):
    library = "react-icons/fc"
    tag = "FcWiFiLogo"


class FcWikipedia(rx.Component):
    library = "react-icons/fc"
    tag = "FcWikipedia"


class FcWorkflow(rx.Component):
    library = "react-icons/fc"
    tag = "FcWorkflow"


